@@ -1,15 +1,16 @@
-from django.http import HttpResponseRedirect
-from django.shortcuts import get_object_or_404
+from django.shortcuts import get_object_or_404, redirect
 from django.views.generic import ListView, DetailView, CreateView, View
 from django.contrib import messages
 from oscar.core.loading import get_model
 from django.utils.translation import ugettext_lazy as _
 
 from oscar.core.loading import get_classes
+from oscar.core.utils import redirect_to_referrer
 from oscar.apps.catalogue.reviews.signals import review_added
 
-ProductReviewForm, VoteForm = get_classes(
-    'catalogue.reviews.forms', ['ProductReviewForm', 'VoteForm'])
+ProductReviewForm, VoteForm, SortReviewsForm = get_classes(
+    'catalogue.reviews.forms',
+    ['ProductReviewForm', 'VoteForm', 'SortReviewsForm'])
 Vote = get_model('reviews', 'vote')
 ProductReview = get_model('reviews', 'ProductReview')
 Product = get_model('catalogue', 'product')
@@ -32,7 +33,7 @@ class CreateProductReview(CreateView):
             else:
                 message = _("You can't leave a review for this product.")
             messages.warning(self.request, message)
-            return HttpResponseRedirect(self.product.get_absolute_url())
+            return redirect(self.product.get_absolute_url())
 
         return super(CreateProductReview, self).dispatch(
             request, *args, **kwargs)
@@ -98,8 +99,7 @@ class AddVoteView(View):
             for error_list in form.errors.values():
                 for msg in error_list:
                     messages.error(request, msg)
-        return HttpResponseRedirect(
-            request.META.get('HTTP_REFERER', product.get_absolute_url()))
+        return redirect_to_referrer(request.META, product.get_absolute_url())
 
 
 class ProductReviewList(ListView):
@@ -114,13 +114,16 @@ class ProductReviewList(ListView):
 
     def get_queryset(self):
         qs = self.model.approved.filter(product=self.kwargs['product_pk'])
-        if 'sort_by' in self.request.GET \
-                and self.request.GET['sort_by'] == 'score':
-            return qs.order_by('-score')
-        return qs.order_by('-date_created')
+        self.form = SortReviewsForm(self.request.GET)
+        if self.form.is_valid():
+            sort_by = self.form.cleaned_data['sort_by']
+            if sort_by == SortReviewsForm.SORT_BY_RECENCY:
+                return qs.order_by('-date_created')
+        return qs.order_by('-score')
 
     def get_context_data(self, **kwargs):
         context = super(ProductReviewList, self).get_context_data(**kwargs)
         context['product'] = get_object_or_404(
             self.product_model, pk=self.kwargs['product_pk'])
+        context['form'] = self.form
         return context
