@@ -7,11 +7,12 @@ from django.contrib.auth import forms as auth_forms
 from django.contrib.auth.forms import AuthenticationForm
 from django.contrib.sites.models import get_current_site
 from django.core.exceptions import ValidationError
+from django.utils.http import is_safe_url
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import pgettext_lazy
 
 from oscar.core.loading import get_profile_class, get_class, get_model
-from oscar.core.compat import get_user_model, existing_user_fields, urlparse
+from oscar.core.compat import get_user_model, existing_user_fields
 from oscar.apps.customer.utils import get_password_reset_url, normalise_email
 from oscar.core.validators import password_validators
 
@@ -53,13 +54,10 @@ class PasswordResetForm(auth_forms.PasswordResetForm):
         if domain_override is not None:
             site.domain = site.name = domain_override
         email = self.cleaned_data['email']
-        users = User._default_manager.filter(email__iexact=email)
-        for user in users:
-            # Build reset url
-            reset_url = "%s://%s%s" % (
-                'https' if use_https else 'http',
-                site.domain,
-                get_password_reset_url(user))
+        active_users = User._default_manager.filter(
+            email__iexact=email, is_active=True)
+        for user in active_users:
+            reset_url = self.get_reset_url(site, request, user, use_https)
             ctx = {
                 'user': user,
                 'site': site,
@@ -68,6 +66,16 @@ class PasswordResetForm(auth_forms.PasswordResetForm):
                 code=self.communication_type_code, context=ctx)
             Dispatcher().dispatch_user_messages(user, messages)
 
+    def get_reset_url(self, site, request, user, use_https):
+        # the request argument isn't used currently, but implementors might
+        # need it to determine the correct subdomain
+        reset_url = "%s://%s%s" % (
+            'https' if use_https else 'http',
+            site.domain,
+            get_password_reset_url(user))
+
+        return reset_url
+
 
 class SetPasswordForm(auth_forms.SetPasswordForm):
     def __init__(self, *args, **kwargs):
@@ -89,7 +97,7 @@ class EmailAuthenticationForm(AuthenticationForm):
     usernames. 75 character usernames are needed to support the EmailOrUsername
     auth backend.
     """
-    username = forms.EmailField(label=_('Email Address'))
+    username = forms.EmailField(label=_('Email address'))
     redirect_url = forms.CharField(
         widget=forms.HiddenInput, required=False)
 
@@ -99,12 +107,8 @@ class EmailAuthenticationForm(AuthenticationForm):
 
     def clean_redirect_url(self):
         url = self.cleaned_data['redirect_url'].strip()
-        if not url:
-            return settings.LOGIN_REDIRECT_URL
-        host = urlparse.urlparse(url)[1]
-        if host and host != self.host:
-            return settings.LOGIN_REDIRECT_URL
-        return url
+        if url and is_safe_url(url):
+            return url
 
 
 class ConfirmPasswordForm(forms.Form):
@@ -146,8 +150,11 @@ class EmailUserCreationForm(forms.ModelForm):
         super(EmailUserCreationForm, self).__init__(*args, **kwargs)
 
     def clean_email(self):
+        """
+        Checks for existing users with the supplied email address.
+        """
         email = normalise_email(self.cleaned_data['email'])
-        if User._default_manager.filter(email=email).exists():
+        if User._default_manager.filter(email__iexact=email).exists():
             raise forms.ValidationError(
                 _("A user with that email address already exists"))
         return email
@@ -162,12 +169,9 @@ class EmailUserCreationForm(forms.ModelForm):
 
     def clean_redirect_url(self):
         url = self.cleaned_data['redirect_url'].strip()
-        if not url:
-            return settings.LOGIN_REDIRECT_URL
-        host = urlparse.urlparse(url)[1]
-        if host and self.host and host != self.host:
-            return settings.LOGIN_REDIRECT_URL
-        return url
+        if url and is_safe_url(url):
+            return url
+        return settings.LOGIN_REDIRECT_URL
 
     def save(self, commit=True):
         user = super(EmailUserCreationForm, self).save(commit=False)
@@ -273,9 +277,10 @@ class UserForm(forms.ModelForm):
         """
         email = normalise_email(self.cleaned_data['email'])
         if User._default_manager.filter(
-                email=email).exclude(id=self.user.id).exists():
+                email__iexact=email).exclude(id=self.user.id).exists():
             raise ValidationError(
                 _("A user with this email address already exists"))
+        # Save the email unaltered
         return email
 
     class Meta:
@@ -299,7 +304,7 @@ if Profile:
             super(UserAndProfileForm, self).__init__(*args, **kwargs)
 
             # Get profile field names to help with ordering later
-            profile_field_names = self.fields.keys()
+            profile_field_names = list(self.fields.keys())
 
             # Get user field names (we look for core user fields first)
             core_field_names = set([f.name for f in User._meta.fields])
@@ -333,8 +338,10 @@ if Profile:
 
         def clean_email(self):
             email = normalise_email(self.cleaned_data['email'])
-            if User._default_manager.filter(
-                    email=email).exclude(id=self.instance.user.id).exists():
+
+            users_with_email = User._default_manager.filter(
+                email__iexact=email).exclude(id=self.instance.user.id)
+            if users_with_email.exists():
                 raise ValidationError(
                     _("A user with this email address already exists"))
             return email
@@ -385,7 +392,7 @@ class ProductAlertForm(forms.ModelForm):
         if email:
             try:
                 ProductAlert.objects.get(
-                    product=self.product, email=email,
+                    product=self.product, email__iexact=email,
                     status=ProductAlert.ACTIVE)
             except ProductAlert.DoesNotExist:
                 pass
