@@ -1,23 +1,22 @@
-from django.conf.urls import patterns, url
+from django.conf.urls import url
 
 from oscar.core.application import Application
-from oscar.apps.dashboard.ranges import views
+from oscar.core.loading import get_class
 
 
 class RangeDashboardApplication(Application):
     name = None
     default_permissions = ['is_staff', ]
 
-    list_view = views.RangeListView
-    create_view = views.RangeCreateView
-    update_view = views.RangeUpdateView
-    delete_view = views.RangeDeleteView
-    products_view = views.RangeProductListView
-    reorder_view = views.RangeReorderView
+    list_view = get_class('dashboard.ranges.views', 'RangeListView')
+    create_view = get_class('dashboard.ranges.views', 'RangeCreateView')
+    update_view = get_class('dashboard.ranges.views', 'RangeUpdateView')
+    delete_view = get_class('dashboard.ranges.views', 'RangeDeleteView')
+    products_view = get_class('dashboard.ranges.views', 'RangeProductListView')
+    reorder_view = get_class('dashboard.ranges.views', 'RangeReorderView')
 
     def get_urls(self):
-        urlpatterns = patterns(
-            '',
+        urlpatterns = [
             url(r'^$', self.list_view.as_view(), name='range-list'),
             url(r'^create/$', self.create_view.as_view(), name='range-create'),
             url(r'^(?P<pk>\d+)/$', self.update_view.as_view(),
@@ -28,7 +27,7 @@ class RangeDashboardApplication(Application):
                 name='range-products'),
             url(r'^(?P<pk>\d+)/reorder/$', self.reorder_view.as_view(),
                 name='range-reorder'),
-        )
+        ]
         return self.post_process_urls(urlpatterns)
 
 
