@@ -1,18 +1,18 @@
-from django.conf.urls import patterns, url
+from django.conf.urls import url
 
 from oscar.core.application import Application
-from oscar.apps.dashboard.vouchers import views
+from oscar.core.loading import get_class
 
 
 class VoucherDashboardApplication(Application):
     name = None
     default_permissions = ['is_staff', ]
 
-    list_view = views.VoucherListView
-    create_view = views.VoucherCreateView
-    update_view = views.VoucherUpdateView
-    delete_view = views.VoucherDeleteView
-    stats_view = views.VoucherStatsView
+    list_view = get_class('dashboard.vouchers.views', 'VoucherListView')
+    create_view = get_class('dashboard.vouchers.views', 'VoucherCreateView')
+    update_view = get_class('dashboard.vouchers.views', 'VoucherUpdateView')
+    delete_view = get_class('dashboard.vouchers.views', 'VoucherDeleteView')
+    stats_view = get_class('dashboard.vouchers.views', 'VoucherStatsView')
 
     def get_urls(self):
         urls = [
@@ -26,7 +26,7 @@ class VoucherDashboardApplication(Application):
             url(r'^stats/(?P<pk>\d+)/$', self.stats_view.as_view(),
                 name='voucher-stats'),
         ]
-        return self.post_process_urls(patterns('', *urls))
+        return self.post_process_urls(urls)
 
 
 application = VoucherDashboardApplication()
