@@ -5,7 +5,7 @@ from django.core.urlresolvers import reverse
 from oscar.core.loading import get_model
 from django.http import HttpResponseRedirect
 from django.utils.translation import ugettext_lazy as _
-from django.views.generic import (ListView, FormView, DetailView, DeleteView)
+from django.views import generic
 
 from oscar.core.loading import get_class
 from oscar.views import sort_queryset
@@ -19,7 +19,7 @@ Condition = get_model('offer', 'Condition')
 OrderDiscount = get_model('order', 'OrderDiscount')
 
 
-class VoucherListView(ListView):
+class VoucherListView(generic.ListView):
     model = Voucher
     context_object_name = 'vouchers'
     template_name = 'dashboard/vouchers/voucher_list.html'
@@ -37,7 +37,8 @@ class VoucherListView(ListView):
                                 'code_filter': ''}
 
         # If form not submitted, return early
-        if 'name' not in self.request.GET:
+        is_form_submitted = 'name' in self.request.GET
+        if not is_form_submitted:
             self.form = self.form_class()
             return qs
 
@@ -63,12 +64,16 @@ class VoucherListView(ListView):
 
     def get_context_data(self, **kwargs):
         ctx = super(VoucherListView, self).get_context_data(**kwargs)
-        ctx['description'] = self.description_template % self.description_ctx
+        if self.form.is_bound:
+            description = self.description_template % self.description_ctx
+        else:
+            description = _("Vouchers")
+        ctx['description'] = description
         ctx['form'] = self.form
         return ctx
 
 
-class VoucherCreateView(FormView):
+class VoucherCreateView(generic.FormView):
     model = Voucher
     template_name = 'dashboard/vouchers/voucher_form.html'
     form_class = VoucherForm
@@ -93,7 +98,7 @@ class VoucherCreateView(FormView):
         name = form.cleaned_data['name']
         offer = ConditionalOffer.objects.create(
             name=_("Offer for voucher '%s'") % name,
-            offer_type="Voucher",
+            offer_type=ConditionalOffer.VOUCHER,
             benefit=benefit,
             condition=condition,
         )
@@ -112,7 +117,7 @@ class VoucherCreateView(FormView):
         return reverse('dashboard:voucher-list')
 
 
-class VoucherStatsView(DetailView):
+class VoucherStatsView(generic.DetailView):
     model = Voucher
     template_name = 'dashboard/vouchers/voucher_detail.html'
     context_object_name = 'voucher'
@@ -125,9 +130,9 @@ class VoucherStatsView(DetailView):
         return ctx
 
 
-class VoucherUpdateView(FormView):
-    model = Voucher
+class VoucherUpdateView(generic.FormView):
     template_name = 'dashboard/vouchers/voucher_form.html'
+    model = Voucher
     form_class = VoucherForm
 
     def get_voucher(self):
@@ -137,7 +142,8 @@ class VoucherUpdateView(FormView):
 
     def get_context_data(self, **kwargs):
         ctx = super(VoucherUpdateView, self).get_context_data(**kwargs)
-        ctx['title'] = _('Update voucher')
+        ctx['title'] = self.voucher.name
+        ctx['voucher'] = self.voucher
         return ctx
 
     def get_form_kwargs(self):
@@ -186,7 +192,7 @@ class VoucherUpdateView(FormView):
         return reverse('dashboard:voucher-list')
 
 
-class VoucherDeleteView(DeleteView):
+class VoucherDeleteView(generic.DeleteView):
     model = Voucher
     template_name = 'dashboard/vouchers/voucher_delete.html'
     context_object_name = 'voucher'
