@@ -1,7 +1,7 @@
 from decimal import Decimal as D
 import datetime
 
-from django.db.models import get_model
+from oscar.core.loading import get_model
 from django.utils.translation import ugettext_lazy as _
 
 from oscar.core.loading import get_class
