@@ -1,4 +1,4 @@
-from six.moves import map
+from django.utils.six.moves import map
 VISA, VISA_ELECTRON, MASTERCARD, AMEX, MAESTRO, DISCOVER = (
     'Visa', 'Visa Electron', 'Mastercard', 'American Express',
     'Maestro', 'Discover')
