@@ -17,8 +17,10 @@ var oscar = (function(o, $) {
         init: function(options) {
             // Run initialisation that should take place on every page of the dashboard.
             var defaults = {
+                'languageCode': 'en',
                 'dateFormat': 'yy-mm-dd',
-                'timeFormat': 'HH:mm',
+                'timeFormat': 'hh:ii',
+                'datetimeFormat': 'yy-mm-dd hh:ii',
                 'stepMinute': 15,
                 'tinyConfig': {
                     statusbar: false,
@@ -67,9 +69,13 @@ var oscar = (function(o, $) {
              * twice for these elements. Make sure that that is harmless.
              */
             o.dashboard.initDatePickers(el);
+            o.dashboard.initMasks(el);
             o.dashboard.initWYSIWYG(el);
             o.dashboard.initSelects(el);
         },
+        initMasks: function(el) {
+            $(el).find(':input').inputmask()
+        },
         initSelects: function(el) {
             // Adds type/search for select fields
             var $selects = $(el).find('select').not('.no-widget-init select').not('.no-widget-init');
@@ -122,43 +128,58 @@ var oscar = (function(o, $) {
             });
         },
         initDatePickers: function(el) {
-            // Use datepicker for all inputs that have 'date' or 'datetime' in the name
-            $inputs = $(el).find('input').not('.no-widget-init input').not('.no-widget-init');
-            if ($.datepicker) {
-                var defaultDatepickerConfig = {'dateFormat': o.dashboard.options.dateFormat};
-                $inputs.filter('[name^="date"], [name$="date"]').each(function(ind, ele) {
+            if ($.fn.datetimepicker) {
+                var defaultDatepickerConfig = {
+                    'format': o.dashboard.options.dateFormat,
+                    'autoclose': true,
+                    'language': o.dashboard.options.languageCode,
+                    'minView': 2
+                };
+                $dates = $(el).find('[data-oscarWidget="date"]').not('.no-widget-init').not('.no-widget-init *')
+                $dates.each(function(ind, ele) {
                     var $ele = $(ele),
                         config = $.extend({}, defaultDatepickerConfig, {
-                            'dateFormat': $ele.data('dateformat')
+                            'format': $ele.data('dateformat')
                         });
-                    $ele.datepicker(config);
+                    $ele.datetimepicker(config);
+                    $ele.find('input').css('width', '125px');
                 });
-            }
-            if ($.ui.timepicker) {
+
                 var defaultDatetimepickerConfig = {
-                    'dateFormat': o.dashboard.options.dateFormat,
-                    'timeFormat': o.dashboard.options.timeFormat,
-                    'stepMinute': o.dashboard.options.stepMinute
+                    'format': o.dashboard.options.datetimeFormat,
+                    'minuteStep': o.dashboard.options.stepMinute,
+                    'autoclose': true,
+                    'language': o.dashboard.options.languageCode
                 };
-                $inputs.filter('[name$="datetime"]').each(function(ind, ele) {
+                $datetimes = $(el).find('[data-oscarWidget="datetime"]').not('.no-widget-init').not('.no-widget-init *')
+                $datetimes.each(function(ind, ele) {
                     var $ele = $(ele),
                         config = $.extend({}, defaultDatetimepickerConfig, {
-                        'dateFormat': $ele.data('dateformat'),
-                        'timeFormat': $ele.data('timeformat'),
-                        'stepMinute': $ele.data('stepminute')});
+                          'format': $ele.data('datetimeformat'),
+                          'minuteStep': $ele.data('stepminute')
+                        });
                     $ele.datetimepicker(config);
+                    $ele.find('input').css('width', '125px');
                 });
 
                 var defaultTimepickerConfig = {
-                    'timeFormat': o.dashboard.options.timeFormat,
-                    'stepMinute': o.dashboard.options.stepMinute
+                    'format': o.dashboard.options.timeFormat,
+                    'minuteStep': o.dashboard.options.stepMinute,
+                    'autoclose': true,
+                    'language': o.dashboard.options.languageCode
                 };
-                $inputs.filter('[name$="time"]').not('[name$="datetime"]').each(function(ind, ele) {
+                $times = $(el).find('[data-oscarWidget="time"]').not('.no-widget-init').not('.no-widget-init *')
+                $times.each(function(ind, ele) {
                     var $ele = $(ele),
                         config = $.extend({}, defaultTimepickerConfig, {
-                        'timeFormat': $ele.data('timeformat'),
-                        'stepMinute': $ele.data('stepminute')});
-                    $ele.timepicker(config);
+                          'format': $ele.data('timeformat'),
+                          'minuteStep': $ele.data('stepminute'),
+                          'startView': 1,
+                          'maxView': 1,
+                          'formatViewType': 'time'
+                        });
+                    $ele.datetimepicker(config);
+                    $ele.find('input').css('width', '125px');
                 });
             }
         },
