@@ -1,3 +1,4 @@
+# coding=utf-8
 from decimal import Decimal as D
 import random
 import datetime
@@ -9,6 +10,7 @@ from oscar.core.loading import get_model
 from oscar.apps.partner import strategy, availability, prices
 from oscar.core.loading import get_class
 from oscar.apps.offer import models
+from oscar.test.newfactories import *  # noqa
 
 Basket = get_model('basket', 'Basket')
 Free = get_class('shipping.methods', 'Free')
@@ -23,6 +25,7 @@ Product = get_model('catalogue', 'Product')
 ProductClass = get_model('catalogue', 'ProductClass')
 ProductAttribute = get_model('catalogue', 'ProductAttribute')
 ProductAttributeValue = get_model('catalogue', 'ProductAttributeValue')
+ProductImage = get_model('catalogue', 'ProductImage')
 
 
 def create_stockrecord(product=None, price_excl_tax=None, partner_sku=None,
@@ -35,9 +38,9 @@ def create_stockrecord(product=None, price_excl_tax=None, partner_sku=None,
     if partner_users:
         for user in partner_users:
             partner.users.add(user)
-    if not price_excl_tax:
+    if price_excl_tax is None:
         price_excl_tax = D('9.99')
-    if not partner_sku:
+    if partner_sku is None:
         partner_sku = 'sku_%d_%d' % (product.id, random.randint(0, 10000))
     return product.stockrecords.create(
         partner=partner, partner_sku=partner_sku,
@@ -52,13 +55,14 @@ def create_purchase_info(record):
             record.price_excl_tax,
             D('0.00')  # Default to no tax
         ),
-        availability=availability.DelegateToStockRecord(record),
+        availability=availability.StockRequired(
+            record.net_stock_level),
         stockrecord=record
     )
 
 
-def create_product(upc=None, title=u"Dummy title",
-                   product_class=u"Dummy item class",
+def create_product(upc=None, title=u"Dùｍϻϒ title",
+                   product_class=u"Dùｍϻϒ item class",
                    partner_name=None, partner_sku=None, price=None,
                    num_in_stock=None, attributes=None,
                    partner_users=None, **kwargs):
@@ -70,11 +74,12 @@ def create_product(upc=None, title=u"Dummy title",
     product = product_class.products.model(
         product_class=product_class,
         title=title, upc=upc, **kwargs)
+    if kwargs.get('parent') and 'structure' not in kwargs:
+        product.structure = 'child'
     if attributes:
         for code, value in attributes.items():
             # Ensure product attribute exists
-            product_class.attributes.get_or_create(
-                name=code, code=code)
+            product_class.attributes.get_or_create(name=code, code=code)
             setattr(product.attr, code, value)
     product.save()
 
@@ -89,6 +94,28 @@ def create_product(upc=None, title=u"Dummy title",
     return product
 
 
+def create_product_image(product=None,
+                         original=None,
+                         caption='Dummy Caption',
+                         display_order=None,
+                         ):
+    if not product:
+        product = create_product()
+    if not display_order:
+        if not product.images.all():
+            display_order = 0
+        else:
+            display_order = max(
+                [i.display_order for i in product.images.all()])+1
+
+    kwargs = {'product_id': product.id,
+              'original': original,
+              'display_order': display_order,
+              'caption': caption, }
+
+    return ProductImage.objects.create(**kwargs)
+
+
 def create_basket(empty=False):
     basket = Basket.objects.create()
     basket.strategy = strategy.Default()
@@ -116,14 +143,16 @@ def create_order(number=None, basket=None, user=None, shipping_address=None,
         basket.save()
     if shipping_method is None:
         shipping_method = Free()
+    shipping_charge = shipping_method.calculate(basket)
     if total is None:
-        total = OrderTotalCalculator().calculate(basket, shipping_method)
+        total = OrderTotalCalculator().calculate(basket, shipping_charge)
     order = OrderCreator().place_order(
         order_number=number,
         user=user,
         basket=basket,
         shipping_address=shipping_address,
         shipping_method=shipping_method,
+        shipping_charge=shipping_charge,
         billing_address=billing_address,
         total=total,
         **kwargs)
@@ -131,7 +160,7 @@ def create_order(number=None, basket=None, user=None, shipping_address=None,
     return order
 
 
-def create_offer(name="Dummy offer", offer_type="Site",
+def create_offer(name=u"Dùｍϻϒ offer", offer_type="Site",
                  max_basket_applications=None, range=None, condition=None,
                  benefit=None, priority=0, status=None, start=None, end=None):
     """
@@ -139,7 +168,7 @@ def create_offer(name="Dummy offer", offer_type="Site",
     """
     if range is None:
         range, __ = models.Range.objects.get_or_create(
-            name="All products range", includes_all_products=True)
+            name=u"All products räñgë", includes_all_products=True)
     if condition is None:
         condition, __ = models.Condition.objects.get_or_create(
             range=range, type=models.Condition.COUNT, value=1)
@@ -173,7 +202,7 @@ def create_voucher():
     Helper method for creating a voucher
     """
     voucher = Voucher.objects.create(
-        name="Test voucher",
+        name=u"Dùｍϻϒ voucher",
         code="test",
         start_datetime=timezone.now(),
         end_datetime=timezone.now() + datetime.timedelta(days=12))
